==> xcsoar-6.5.3.tar.bz2: xcsoar-6.5.3/src/Screen/GDI/Init.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "Screen/Init.hpp"
#include "Screen/Debug.hpp"
#include "Screen/GDI/AlphaBlend.hpp"
#include "Screen/PaintWindow.hpp"
#include "Screen/SingleWindow.hpp"

#include <windows.h>
#include <commctrl.h>

ScreenGlobalInit::ScreenGlobalInit()
{
  InitCommonControls();

#ifdef HAVE_DYNAMIC_ALPHA_BLEND
  AlphaBlendInit();
#endif

  HINSTANCE hInstance = ::GetModuleHandle(NULL);
  PaintWindow::register_class(hInstance);
  SingleWindow::RegisterClass(hInstance);

  ScreenInitialized();
}

ScreenGlobalInit::~ScreenGlobalInit()
{
#ifdef HAVE_DYNAMIC_ALPHA_BLEND
  AlphaBlendDeinit();
#endif

  ScreenDeinitialized();
}

==> xcsoar-6.7.1.tar.bz2: xcsoar-6.7.1/src/Screen/GDI/Init.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "Screen/Init.hpp"
#include "Screen/Debug.hpp"
#include "Screen/GDI/AlphaBlend.hpp"
#include "Screen/PaintWindow.hpp"
#include "Screen/SingleWindow.hpp"
#include "Event/Globals.hpp"
#include "Event/Queue.hpp"

#include <windows.h>
#include <commctrl.h>

ScreenGlobalInit::ScreenGlobalInit()
{
  InitCommonControls();

#ifdef HAVE_DYNAMIC_ALPHA_BLEND
  AlphaBlendInit();
#endif

  event_queue = new EventQueue();

  HINSTANCE hInstance = ::GetModuleHandle(NULL);
  PaintWindow::register_class(hInstance);
  SingleWindow::RegisterClass(hInstance);

  ScreenInitialized();
}

ScreenGlobalInit::~ScreenGlobalInit()
{
  delete event_queue;
  event_queue = nullptr;

#ifdef HAVE_DYNAMIC_ALPHA_BLEND
  AlphaBlendDeinit();
#endif

  ScreenDeinitialized();
}
